Generation Functions
====================

Below are example generation functions available in libEnsemble.

.. IMPORTANT::
  See the API for generation functions :ref:`here<api_gen_f>`.

.. toctree::
   :maxdepth: 2
   :caption: Example Generator Functions:

   sampling
   aposmm
   uniform_or_localopt
   deap_nsga2
   tasmanian
   fd_param_finder
   vtmop
   surmise
